# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`powershell7`](#powershell7): This is the powershell7 module main class

#### Private Classes

* `powershell7::config`: Configuration options for Powershell 7 once installed
* `powershell7::install`: Install Powershell 7

### Data types

* [`Powershell7::Windowcolor`](#powershell7windowcolor): Creates a new type alias which ensures that the PowerShell Background/Foreground
colors are limited to those that are supported by the application.

## Classes

### <a name="powershell7"></a>`powershell7`

powershell7

This class declares all module parameters and calls the necessary classes
to install PowerShell 7

#### Examples

##### Basic usage

```puppet
include powershell7
```

##### Configuring window defaults

```puppet
class { 'powershell7':
  config_window_width     => 400,
  config_window_height    => 60,
  config_buffer_height    => 6000,
  config_background_color => 'Blue',
  config_foreground_color => 'White',
}
```

##### Using a different download location and version of the installer

```puppet
class {
  lts_file_name  => 'PowerShell-7.0.6-win-x64.msi',
  lts_source_url => 'https://myserver.internal.com/PowerShell/PowerShell-7.0.6-win-x64.msi',
}
```

#### Parameters

The following parameters are available in the `powershell7` class:

* [`os_letter`](#os_letter)
* [`download_dir`](#download_dir)
* [`lts_file_name`](#lts_file_name)
* [`lts_source_url`](#lts_source_url)
* [`stable_file_name`](#stable_file_name)
* [`stable_source_url`](#stable_source_url)
* [`preview_file_name`](#preview_file_name)
* [`preview_source_url`](#preview_source_url)
* [`release_type`](#release_type)
* [`add_explorer_context_menu_openpowershell`](#add_explorer_context_menu_openpowershell)
* [`add_file_context_menu_runpowershell`](#add_file_context_menu_runpowershell)
* [`enable_psremoting`](#enable_psremoting)
* [`register_manifest`](#register_manifest)
* [`powershell_updatecheck`](#powershell_updatecheck)
* [`config_window_width`](#config_window_width)
* [`config_window_height`](#config_window_height)
* [`config_buffer_height`](#config_buffer_height)
* [`config_background_color`](#config_background_color)
* [`config_foreground_color`](#config_foreground_color)

##### <a name="os_letter"></a>`os_letter`

Data type: `Pattern[/^[A-Z]$/]`

The Letter of the disk which has the Windows folder. Defaults to C

##### <a name="download_dir"></a>`download_dir`

Data type: `Stdlib::Absolutepath`

The directory where the downloaded installer is placed.

##### <a name="lts_file_name"></a>`lts_file_name`

Data type: `String`

The name of the LTS PowerShell installer

##### <a name="lts_source_url"></a>`lts_source_url`

Data type: `Stdlib::HTTPUrl`

The internet URL for the LTS Powershell Download

##### <a name="stable_file_name"></a>`stable_file_name`

Data type: `String`

The name of the Stable PowerShell installer

##### <a name="stable_source_url"></a>`stable_source_url`

Data type: `Stdlib::HTTPUrl`

The internet URL for the Stable Powershell Download

##### <a name="preview_file_name"></a>`preview_file_name`

Data type: `String`

The name of the Preview PowerShell installer

##### <a name="preview_source_url"></a>`preview_source_url`

Data type: `Stdlib::HTTPUrl`

The internet URL for the Preview Powershell Download

##### <a name="release_type"></a>`release_type`

Data type: `ENUM['lts','stable','preview']`

Defines which PowerShell release type to be installed. Defaults to stable

##### <a name="add_explorer_context_menu_openpowershell"></a>`add_explorer_context_menu_openpowershell`

Data type: `Integer[0,1]`

Adds a context menu item for explorer and will open a PowerShell window at the current location. Defaults to 1

##### <a name="add_file_context_menu_runpowershell"></a>`add_file_context_menu_runpowershell`

Data type: `Integer[0,1]`

Adds a context menu item to run the selected file in PowerShell. Defaults to 1

##### <a name="enable_psremoting"></a>`enable_psremoting`

Data type: `Integer[0,1]`

Enables PS Remoting during installation. Defaults to 1

##### <a name="register_manifest"></a>`register_manifest`

Data type: `Integer[0,1]`

Enables the Windows Event Logging Manifest. Defaults to 1

##### <a name="powershell_updatecheck"></a>`powershell_updatecheck`

Data type: `ENUM['Off','Default','LTS']`

Sets the update notification policy to alert users to the availability of updates. Defaults to 'Default'

##### <a name="config_window_width"></a>`config_window_width`

Data type: `Integer`

Sets the width of the PowerShell window. This also needs to set the Buffer width also as they can't be different. Defaults to 120

##### <a name="config_window_height"></a>`config_window_height`

Data type: `Integer`

Sets the height of the PowerShell window. Defaults to 30

##### <a name="config_buffer_height"></a>`config_buffer_height`

Data type: `Integer`

Sets how far you can vertically scroll the window to see previous commands and output. Defaults to 9001

##### <a name="config_background_color"></a>`config_background_color`

Data type: `Powershell7::Windowcolor`

Sets the color of the window behind the text. Defaults to 'Black'

##### <a name="config_foreground_color"></a>`config_foreground_color`

Data type: `Powershell7::Windowcolor`

Sets the color of the foreground text color. Defaults to 'White'

## Data types

### <a name="powershell7windowcolor"></a>`Powershell7::Windowcolor`

Powershell7::Windowcolor

Alias of

```puppet
Enum['Black', 'DarkBlue', 'DarkGreen', 'DarkCyan', 'DarkRed', 'DarkMagenta', 'DarkYellow', 'Gray', 'Blue', 'Green', 'Cyan', 'Red', 'Magenta', 'Yellow', 'White']
```
